@@ -958,7 +958,7 @@ class Font:
         subfamily_name = subfamily_name.title()
 
         # full name
-        full_name = concat_names(family_name, subfamily_name)
+        full_name = concat_names(typographic_family_name, typographic_subfamily_name)
 
         # postscript name
         postscript_name = concat_names(
